@@ -28,6 +28,7 @@ from wapitiCore.definitions.resource_consumption import ResourceConsumptionFindi
 from wapitiCore.model import PayloadInfo, str_to_payloadinfo
 from wapitiCore.net import Request, Response
 from wapitiCore.main.log import logging, log_verbose, log_orange, log_red
+from wapitiCore.net.web import http_repr
 
 
 class ModuleCrlf(Attack):
@@ -38,7 +39,7 @@ class ModuleCrlf(Attack):
     MSG_VULN = "CRLF Injection"
     do_get = True
     do_post = True
-    payloads = [PayloadInfo(payload="http://www.google.fr\r\nwapiti: 3.2.6 version")]
+    payloads = [PayloadInfo(payload="http://www.google.fr\r\nwapiti: 3.2.7 version")]
 
     def __init__(self, crawler, persister, attack_options, crawler_configuration):
         super().__init__(crawler, persister, attack_options, crawler_configuration)
@@ -49,7 +50,7 @@ class ModuleCrlf(Attack):
 
         for mutated_request, parameter, _payload in self.mutator.mutate(
                 request,
-                str_to_payloadinfo(["http://www.google.fr\r\nwapiti: 3.2.6 version"]),
+                str_to_payloadinfo(["http://www.google.fr\r\nwapiti: 3.2.7 version"]),
         ):
             log_verbose(f"[¨] {mutated_request.url}")
 
@@ -67,7 +68,7 @@ class ModuleCrlf(Attack):
                 log_orange("---")
                 log_orange(Messages.MSG_TIMEOUT, page)
                 log_orange(Messages.MSG_EVIL_REQUEST)
-                log_orange(mutated_request.http_repr())
+                log_orange(http_repr(mutated_request))
                 log_orange("---")
             except HTTPStatusError:
                 self.network_errors += 1
@@ -97,5 +98,5 @@ class ModuleCrlf(Attack):
                         parameter.display_name
                     )
                     log_red(Messages.MSG_EVIL_REQUEST)
-                    log_red(mutated_request.http_repr())
+                    log_red(http_repr(mutated_request))
                     log_red("---")
